@@ -9,9 +9,11 @@ import humanize
 from .data_transfer import copy_file, get_bytes, put_bytes, delete_object, list_objects
 from .formats import FormatRegistry
 from .packages import Package
+from .search_util import search as util_search
 from .util import (QuiltConfig, QuiltException, CONFIG_PATH,
-                   CONFIG_TEMPLATE, fix_url, parse_file_url, parse_s3_url, read_yaml, validate_url,
-                   write_yaml, validate_package_name, get_from_config, get_package_registry)
+                   CONFIG_TEMPLATE, find_bucket_config, fix_url, get_from_config,
+                   get_package_registry, parse_file_url, parse_s3_url, read_yaml,
+                   validate_url, validate_package_name, write_yaml)
 
 
 def copy(src, dest):
@@ -302,7 +304,6 @@ def list_packages(registry=None):
                     {'pkg_name': pkg_display_name, 'top_hash': top_hash,
                      'ctime': ctime, 'size': size}
                 )
-
     elif registry_scheme == 's3':
         bucket_name, bucket_registry_path, _ = parse_s3_url(named_packages_urlparse)
         bucket_registry_path = bucket_registry_path + '/'
@@ -320,7 +321,7 @@ def list_packages(registry=None):
             raw_pkg_names = [pkg_name['Prefix'] for pkg_name in raw_pkg_names]
 
             # go through packages to get package hash files
-            for pkg_name in raw_pkg_names:
+            for raw_pkg_name in raw_pkg_names:
                 pkg_hashes = []
                 pkg_sizes = []
                 pkg_ctimes = []
@@ -328,10 +329,13 @@ def list_packages(registry=None):
 
                 _, pkg_hashfiles = list_objects(
                     bucket_name,
-                    pkg_name,
+                    raw_pkg_name,
                     recursive=False
                 )
 
+                # Trim registry prefix from path
+                pkg_name = raw_pkg_name[len(bucket_registry_path):].strip('/')
+
                 latest_hashfile = next(hf for hf in pkg_hashfiles if '/latest' in hf['Key'])['Key']
                 latest_hashfile_fullpath = f's3://{bucket_name}/{latest_hashfile}'
                 latest_hash, _ = get_bytes(latest_hashfile_fullpath)
@@ -354,7 +358,7 @@ def list_packages(registry=None):
 
                 # go through manifest files to get package info
                 for pkg_hash_path in pkg_hash_paths:
-                    pkg_display_name = pkg_name[len(bucket_registry_path):].strip('/')
+                    pkg_display_name = pkg_name
 
                     pkg_hash, _ = get_bytes('s3://' + bucket_name + '/' + pkg_hash_path)
                     pkg_hash = pkg_hash.decode()
@@ -475,3 +479,42 @@ def config(*catalog_url, **config_values):
 
     # Return current config
     return QuiltConfig(CONFIG_PATH, local_config)
+
+def search(query, limit=10):
+    """
+    Execute a search against the configured search endpoint.
+
+    Args:
+        query (str): query string to search
+        limit (number): maximum number of results to return. Defaults to 10
+
+    Query Syntax:
+        By default, a normal plaintext search will be executed over the query string.
+        You can use field-match syntax to filter on exact matches for fields in
+            your metadata.
+        The syntax for field match is `user_meta.$field_name:"exact_match"`.
+
+    Returns:
+        either the request object (in case of an error) or
+        a list of objects with the following structure:
+        ```
+        [{
+            "key": <key of the object>,
+            "version_id": <version_id of object version>,
+            "operation": <"Create" or "Delete">,
+            "meta": <metadata attached to object>,
+            "size": <size of object in bytes>,
+            "text": <indexed text of object>,
+            "source": <source document for object (what is actually stored in ElasticSeach)>,
+            "time": <timestamp for operation>,
+        }...]
+        ```
+    """
+    default_bucket = get_from_config('defaultBucket')
+    navigator_url = get_from_config('navigator_url')
+    config_url = navigator_url + '/config.json'
+    default_config = find_bucket_config(default_bucket, config_url)
+    search_endpoint = default_config['searchEndpoint']
+    region = default_config['region']
+
+    return util_search(query, search_endpoint, limit=limit, aws_region=region)
